package com.jkcredit.sysnews.config;

import com.alibaba.fastjson.JSONArray;
import com.jkcredit.sysnews.service.security.CustomUserDetailsService;
import com.jkcredit.sysnews.util.JwtTokenUtil;
import io.jsonwebtoken.Claims;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.User;
import org.springframework.security.web.authentication.WebAuthenticationDetailsSource;
import org.springframework.security.web.authentication.www.BasicAuthenticationFilter;

import javax.annotation.Resource;
import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

/**
 * @description:
 * @author: xusonglin
 * @create: 2020/2/27 23:50
 * @version: V1.0
 **/
public class JwtAuthenticationFilter extends BasicAuthenticationFilter {
    @Resource
    CustomUserDetailsService userDetailsService;

    public JwtAuthenticationFilter(AuthenticationManager authenticationManager) {
        super(authenticationManager);
    }

    @Override
    protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain chain) throws IOException, ServletException {

        String header = request.getHeader("Authorization");
        if (header == null || !header.startsWith("Bearer ")) {
            chain.doFilter(request, response);
            return;
        }
        try {
            UsernamePasswordAuthenticationToken authentication = getAuthentication(header, request, response);
            SecurityContextHolder.getContext().setAuthentication(authentication);
        }catch (Exception e){
            e.toString();
        }

        chain.doFilter(request, response);
    }

    private UsernamePasswordAuthenticationToken getAuthentication(String header, HttpServletRequest request, HttpServletResponse response) {
        String authToken = header.substring("Bearer ".length());
        Claims claims = JwtTokenUtil.parseToken(authToken, "_secret");
        String username = claims.getSubject();
//        List<GrantedAuthority> grantedAuthorities = (List<GrantedAuthority>) claims.get("authorities");
        List<SimpleGrantedAuthority> grantedAuthorityList = JSONArray.parseArray(claims.get("authorities").toString()).toJavaList(SimpleGrantedAuthority.class);
        if (username != null && SecurityContextHolder.getContext().getAuthentication() == null) {
            User principal = new User(username, "", grantedAuthorityList);
            UsernamePasswordAuthenticationToken authentication =
                    new UsernamePasswordAuthenticationToken(principal, null, grantedAuthorityList);
            authentication.setDetails(new WebAuthenticationDetailsSource().buildDetails(request));
            return authentication;
        }
        return null;
    }
}
