package com.jkcredit.sysnews.resource.web.navigationBar;

import com.jkcredit.sysnews.model.dto.navigationBar.NavigationBarDto;
import com.jkcredit.sysnews.model.vo.navigationBar.NavigationBarTreeVo;
import com.jkcredit.sysnews.model.vo.navigationBar.NavigationBarVo;
import com.jkcredit.sysnews.resource.base.WebResource;
import com.jkcredit.sysnews.resource.web.navigationBar.fb.NavigationBarAddFB;
import com.jkcredit.sysnews.resource.web.navigationBar.fb.NavigationBarEditFB;
import com.jkcredit.sysnews.service.navigationBar.NavigationBarService;
import com.jkcredit.sysnews.spi.lang.exception.ServiceException;
import com.jkcredit.sysnews.spi.web.data.ResponseData;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;

/**
 * @description:
 * @author: xusonglin
 * @create: 2020/3/2 22:25
 * @version: V1.0
 **/
@Slf4j
@RestController
public class NavigationBarResource extends WebResource {
    @Autowired
    NavigationBarService navigationBarService;

    @PostMapping("/menu")
    @PreAuthorize("hasPermission('menu','edit')")
    @ApiOperation(value = "新增菜单栏")
    public ResponseData saveNavigationBar(NavigationBarAddFB navigationBarAddFB) {
        try {
            NavigationBarDto navigationBarDto = mapper.map(navigationBarAddFB, NavigationBarDto.class);
            navigationBarService.saveNavigationBar(navigationBarDto);
            return ResponseData.success("新增菜单栏成功");
        } catch (ServiceException e) {
            log.error(e.getMessage());
            return ResponseData.failed("新增菜单栏失败,失败原因：" + e.getMessage());
        }
    }

    @GetMapping("/menu")
    @PreAuthorize("hasPermission('menu','read')")
    @ApiOperation(value = "获取树状菜单栏")
    public ResponseData getNavigationBar() {
        try {
            List<NavigationBarTreeVo> result = navigationBarService.getNavigationBars(new NavigationBarDto());
            return ResponseData.success(result);
        } catch (ServiceException e) {
            log.error(e.getMessage());
            return ResponseData.failed("获取树状菜单栏失败");
        }
    }

    @GetMapping("/menu/{id}")
    @PreAuthorize("hasPermission('menu','read')")
    @ApiOperation(value = "根据id获取菜单栏信息")
    public ResponseData getNavigationBarById(@PathVariable Long id) {
        try {
            NavigationBarVo navigationBarVo = navigationBarService.getNavigationBarById(id);
            return ResponseData.success(navigationBarVo);
        } catch (ServiceException e) {
            log.error(e.getMessage());
            return ResponseData.failed("获取菜单栏信息失败");
        }
    }

    @PutMapping("/menu/{id}")
    @PreAuthorize("hasPermission('menu','edit')")
    @ApiOperation(value = "删除菜单栏")
    public ResponseData deleteNavigationBar(@PathVariable Long id) {
        try {
            navigationBarService.deleteNavigationBar(id);
            return ResponseData.success("删除菜单栏成功");
        } catch (ServiceException e) {
            log.error(e.getMessage());
            return ResponseData.failed(e.getMessage());
        }
    }

    @PutMapping("/menu")
    @PreAuthorize("hasPermission('menu','edit')")
    @ApiOperation(value = "修改菜单栏信息")
    public ResponseData updateNavigationBar(NavigationBarEditFB navigationBarEditFB) {
        try {
            validate(navigationBarEditFB);
            NavigationBarDto navigationBarDto = mapper.map(navigationBarEditFB, NavigationBarDto.class);
            navigationBarService.editNavigationBar(navigationBarDto);
            return ResponseData.success("修改菜单栏成功");
        } catch (ServiceException e) {
            log.error(e.getMessage());
            return ResponseData.failed("修改菜单栏失败");
        }

    }
}
