package com.jkcredit.sysnews.resource.web.photo;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jkcredit.sysnews.model.dto.photo.PhotoDto;
import com.jkcredit.sysnews.model.vo.photo.PhotoVo;
import com.jkcredit.sysnews.resource.base.WebResource;
import com.jkcredit.sysnews.resource.web.photo.fb.PhotoEditFB;
import com.jkcredit.sysnews.resource.web.photo.fb.PhotoFB;
import com.jkcredit.sysnews.resource.web.photo.fb.PhotoQueryFB;
import com.jkcredit.sysnews.service.photo.PhotoService;
import com.jkcredit.sysnews.spi.lang.exception.ServiceException;
import com.jkcredit.sysnews.spi.web.data.ResponseData;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * @description:
 * @author: xusonglin
 * @create: 2020/3/1 0:25
 * @version: V1.0
 **/
@Slf4j
@RestController
public class PhotoResource extends WebResource {
    @Autowired
    PhotoService photoService;

    @PostMapping("/upload")
    @PreAuthorize("hasPermission('photo','upload')")
    @ApiOperation(value = "上传图片")
    public ResponseData upload(@RequestParam("photo") MultipartFile photo) {
        if (photo == null) {
            return ResponseData.failed("上传失败，图片不能为空！");
        }
        try {
            String url = photoService.upload(photo);
            return ResponseData.success((Object) url);
        } catch (ServiceException e) {
            return ResponseData.failed("图片上传失败");
        }
    }

    @GetMapping("/page/photos")
    @PreAuthorize("hasPermission('photo','read')")
    @ApiOperation(value = "获取图片列表")
    public ResponseData getPhotos(Page page, PhotoQueryFB queryFB) {
        try {
            PhotoDto photoDto = mapper.map(queryFB, PhotoDto.class);
            IPage<PhotoVo> photos = photoService.getPhotos(page, photoDto);
            return ResponseData.success(photos);
        } catch (ServiceException e) {
            return ResponseData.failed("获取图片列表失败");
        }
    }

    @GetMapping("/photo/{id}")
    @PreAuthorize("hasPermission('photo','read')")
    @ApiOperation(value = "根据id获取图片信息")
    public ResponseData getPhotoById(@PathVariable("id") Long id) {
        try {
            PhotoVo photoVo = photoService.getPhotoById(id);
            return ResponseData.success(photoVo);
        } catch (Exception e) {
            return ResponseData.failed("获取图片信息失败");
        }
    }

    @PostMapping("/photo")
    @PreAuthorize("hasPermission('photo','edit')")
    @ApiOperation(value = "新增图片信息")
    public ResponseData savePhoto(PhotoFB photoFB) {
        try {
            validate(photoFB);

            PhotoDto photoDto = mapper.map(photoFB, PhotoDto.class);
            PhotoVo photoVo = photoService.savePhoto(photoDto);

            return ResponseData.success(photoVo);
        } catch (ServiceException e) {
            log.error(e.getMessage());
            return ResponseData.failed("新增图片失败,失败原因：" + e.getMessage());
        }
    }

    @PutMapping("/photo")
    @PreAuthorize("hasPermission('photo','edit')")
    @ApiOperation(value = "编辑图片信息")
    public ResponseData updatePhoto(PhotoEditFB photoFB) {
        try {
            validate(photoFB);
            PhotoDto photoDto = mapper.map(photoFB, PhotoDto.class);
            photoService.editPhoto(photoDto);

            return ResponseData.success("编辑图片数据成功");
        } catch (ServiceException e) {
            return ResponseData.failed("编辑图片数据，失败原因" + e.getMessage());
        }
    }

    @PutMapping("/photo/{id}")
    @PreAuthorize("hasPermission('photo','edit')")
    @ApiOperation(value = "删除图片信息")
    public ResponseData deletePhoto(@PathVariable("id") Long id) {
        try {
            photoService.deletePhoto(id);
            return ResponseData.success("删除图片成功");
        } catch (ServiceException e) {
            log.error(e.getMessage());
            return ResponseData.failed("删除用户失败");
        }
    }
}
