package com.jkcredit.sysnews.service.newsArticleNavigationBar;

import com.jkcredit.sysnews.mapper.NewsArticleNavigationBarMapper;
import com.jkcredit.sysnews.model.dto.newsArticleNavigationBar.NewsArticleNavigationBarDto;
import com.jkcredit.sysnews.model.po.newsArticleNavigationBar.NewsArticleNavigationBarPo;
import com.jkcredit.sysnews.service.base.BaseService;
import com.jkcredit.sysnews.spi.lang.constant.CommonConstant;
import com.jkcredit.sysnews.spi.lang.exception.ServiceException;
import com.jkcredit.sysnews.util.AssertUtils;
import com.jkcredit.sysnews.util.BeanUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @description:
 * @author: xusonglin
 * @create: 2020/3/11 8:38
 * @version: V1.0
 **/
@Slf4j
@Service
public class NewsArticleNavigationBarServiceImpl extends BaseService implements NewsArticleNavigationBarService {
    @Resource
    NewsArticleNavigationBarMapper mapper;

    @Override
    public List<NewsArticleNavigationBarDto> getArticleNavigationBarByNewsId(Long id) {
        List<NewsArticleNavigationBarPo> poList = mapper.getArticleNavigationBarByNewsId(id);
        List<NewsArticleNavigationBarDto> dtoList = new ArrayList<>();
        for (NewsArticleNavigationBarPo po : poList) {
            NewsArticleNavigationBarDto dto = new NewsArticleNavigationBarDto();
            BeanUtil.copyProperties(dto, po);
            dtoList.add(dto);
        }
        return dtoList;
    }

    @Override
    public void saveNewsArticleNavigationBar(NewsArticleNavigationBarDto dto) {
        NewsArticleNavigationBarPo po = new NewsArticleNavigationBarPo();
        BeanUtil.copyProperties(po, dto);
        po.setCreateTime(new Date());

        try {
            mapper.insert(po);
        } catch (Exception e) {
            log.error("新增导航新闻管理表失败，失败原因{}", e.getMessage());
            throw new ServiceException("新增导航新闻管理表失败");
        }
    }

    @Override
    public void deleteNewsArticleNavigationBar(Long id) {
        NewsArticleNavigationBarPo newsArticleNavigationBarPo = mapper.selectById(id);
        newsArticleNavigationBarPo.setUpdateTime(new Date());
        newsArticleNavigationBarPo.setActivated(CommonConstant.ACTIVATED_DELETED);
        try {
            mapper.updateById(newsArticleNavigationBarPo);
        } catch (Exception e) {
            log.error("删除导航新闻管理表失败，失败原因{}", e.getMessage());
            throw new ServiceException("删除导航新闻管理表失败");
        }
    }

    @Override
    public Long getArticleNavigationBarId(Long articleId, Long navigationBarId) {
        AssertUtils.assertNotNull(articleId, "新闻id不能为空");
        AssertUtils.assertNotNull(navigationBarId, "导航栏id不能为空");
        return mapper.getArticleNavigationBarId(articleId, navigationBarId);
    }

    @Override
    public List<Long> getNavigationBarIdByNewsId(Long id) {
        return mapper.getNavigationBarIdByNewsId(id);
    }
}
