package com.jkcredit.sysnews.service.security;

import com.jkcredit.sysnews.model.po.permission.PermissionPo;
import com.jkcredit.sysnews.model.po.user.UserPo;
import com.jkcredit.sysnews.service.permission.PermissionService;
import com.jkcredit.sysnews.service.user.UserService;
import com.jkcredit.sysnews.spi.lang.exception.ServiceException;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

/**
 * @description:
 * @author: xusonglin
 * @create: 2020/2/27 14:35
 * @version: V1.0
 **/
@Component("userDetailsService")
@Slf4j
public class CustomUserDetailsService implements UserDetailsService {
    @Autowired
    UserService userService;
    @Autowired
    PermissionService permissionService;

    @Override
    public UserDetails loadUserByUsername(String username) throws UsernameNotFoundException {
        log.info("Authenticating {}", username);
        Optional<UserPo> userPo = userService.getUserByUsername(username);
        return userPo.map(user -> createSpringSecurityUser(username, user))
                .orElseThrow(() -> new UsernameNotFoundException("user " + username + " was not found in the database"));
    }

    private org.springframework.security.core.userdetails.User createSpringSecurityUser(String lowercaseLogin, UserPo user) {
        if (!user.getActivated().equals(1)) {
            throw new ServiceException("user " + lowercaseLogin + " was not activated");
        }

        List<PermissionPo> permissionPoList = permissionService.getPermissionsByUserId(user.getId());
        List<GrantedAuthority> grantedAuthorities = new ArrayList<>();
        for (PermissionPo permissionPo : permissionPoList) {
            if (permissionPo.getActivated().equals(1)) {
                SimpleGrantedAuthority simpleGrantedAuthority = new SimpleGrantedAuthority(permissionPo.getPermission());
                grantedAuthorities.add(simpleGrantedAuthority);
            }
        }
        return new org.springframework.security.core.userdetails.User(user.getUsername(), user.getPassword(), grantedAuthorities);
    }
}
